/*
	emk.c - build system including an embedded scripting language

	This file is part of emk.

	emk is free software: you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by the
	Free Software Foundation, either version 3 of the License, or (at your
	option) any later version.

	emk is distributed in the hope that it will be useful, but WITHOUT
	ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
	FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
	for more details.

	You should have received a copy of the GNU General Public License
	along with emk. If not, see <https://www.gnu.org/licenses/>. 
*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "emk.h"

#include "parse.h" /* for compile-time settings */

static void
usage(int argc, char *argv[])
{
	printf("%s - simple build system and scripting language\n", argv[0]);
	printf("usage: %s [-h] [-v]\n", argv[0]);
	printf("\n");
	printf("%s {-h}		Show this message\n", argv[0]);
	printf("%s {-v}		Show the current version\n", argv[0]);
	printf("%s {-s}		View compile-time settings\n", argv[0]);
	printf("\n");
	printf("When no option is passed, %s run in the working directory.\n", argv[0]);
	printf("\n");
	printf("Emk is free software.\n");
	printf("See the GNU GPL version 3 for details.\n");
}

static void
usage_small(int argc, char *argv[])
{
	printf("usage: %s [-h] [-v]\n", argv[0]);
}

int
main(int argc, char *argv[])
{
	int opt;

	while ((opt = getopt(argc,argv, ":if:hvs")) != -1) {
		switch(opt) {
		case 'h':
			usage(argc, argv);
			exit(0);
			break;
		case 'v':
			printf(EMK_VERSION "\n");
			exit(0);
			break;
		case 's':
			printf("Compile-time settings for %s\n", argv[0]);
			printf("EMKFILE: " EMKFILE "\n");
			printf("EMKFILE_NEW: " EMKFILE_NEW "\n");
			printf("EMKCONFIG: " EMKCONFIG "\n");
			exit(0);
			break;
		case '?':
			usage_small(argc,argv);
			exit(1);
			break;
		}
	}

	printf("running emk\n");

	return 0;
}
